@@ -13,9 +13,10 @@ from AIBridge.ai_services.palm_text import PalmText
 from AIBridge.ai_services.palm_chat import PalmChat
 from AIBridge.ai_services.stable_diffusion_image import StableDiffusion
 from AIBridge.ai_services.cohere_llm import CohereApi
-from AIBridge.ai_services.ai21labs_text import JurasicText
+from AIBridge.ai_services.ai21labs_text import AI21labsText
 from AIBridge.ai_services.geminin_services import GeminiAIService
-
+from AIBridge.ai_services.anthropic_ai import AnthropicService
+from AIBridge.ai_services.ollama_services import OllamaService
 
 __all__ = [
     "OpenAIService",
@@ -34,8 +35,10 @@ __all__ = [
     "PalmChat",
     "StableDiffusion",
     "CohereApi",
-    "JurasicText",
+    "AI21labsText",
     "GeminiAIService",
+    "AnthropicService",
+    "OllamaService"
 ]
 
 __version__ = "0.0.0"
