@@ -184,28 +184,44 @@ class AI21labsText(AIInterface):
                 print(response)
                 for res in response.choices:
                     content = res.message.content
-                    if "```json" in content:
-                        content = content.replace("```json", "")
-                        content = content.replace("```", "")
-                    print(content, "xxxxxxxxxxxxxxxxxxxxxxxxxxxxx")
+                    # Make JSON parsing more robust
+                    try:
+                        # First try to parse as direct JSON
+                        content = json.loads(content)
+                    except json.JSONDecodeError:
+                        # If direct parsing fails, try to extract JSON from markdown
+                        if "```json" in content:
+                            # Extract content between ```json and ```
+                            try:
+                                json_content = content.split("```json")[1].split("```")[0]
+                                content = json.loads(json_content.strip())
+                            except (IndexError, json.JSONDecodeError):
+                                # If extraction fails, keep original content
+                                pass
+                        elif "```" in content:
+                            # Try to extract from generic code block
+                            try:
+                                json_content = content.split("```")[1].split("```")[0]
+                                content = json.loads(json_content.strip())
+                            except (IndexError, json.JSONDecodeError):
+                                pass
+                    
                     if output_format:
                         _formatter = output_format[index]
                         try:
                             if _formatter == "csv":
-                                content=json.loads(content)
+                                if isinstance(content, str):
+                                    content = json.loads(content)
                                 if isinstance(content, list):
                                     if len(content) == 1:
                                         content = content[0]
-                                        if isinstance(content, str):
-                                            content = json.loads(content)
                                 content = FromJson.json_to_csv(content)
                             elif _formatter == "xml":
-                                content=json.loads(content)
+                                if isinstance(content, str):
+                                    content = json.loads(content)
                                 if isinstance(content, list):
                                     if len(content) == 1:
                                         content = content[0]
-                                        if isinstance(content, str):
-                                            content = json.loads(content)
                                 content = FromJson.json_to_xml(content)
                         except AIBridgeException as e:
                             raise ValidationException(
