@@ -228,6 +228,22 @@ class CohereApi(AIInterface):
                         }
                     )
                     content = response.message.content[0].text
+                    # Make JSON parsing more robust
+                    try:
+                        content = json.loads(content)
+                    except json.JSONDecodeError:
+                        if "```json" in content:
+                            try:
+                                json_content = content.split("```json")[1].split("```")[0]
+                                content = json.loads(json_content.strip())
+                            except (IndexError, json.JSONDecodeError):
+                                pass
+                        elif "```" in content:
+                            try:
+                                json_content = content.split("```")[1].split("```")[0]
+                                content = json.loads(json_content.strip())
+                            except (IndexError, json.JSONDecodeError):
+                                pass
                 else:
                     if _formatter == "csv":
                         csv=format_structure[index]
@@ -255,6 +271,22 @@ class CohereApi(AIInterface):
                     )
                     print(response)
                     content = response.message.content[0].text
+                    # Make JSON parsing more robust
+                    try:
+                        content = json.loads(content)
+                    except json.JSONDecodeError:
+                        if "```json" in content:
+                            try:
+                                json_content = content.split("```json")[1].split("```")[0]
+                                content = json.loads(json_content.strip())
+                            except (IndexError, json.JSONDecodeError):
+                                pass
+                        elif "```" in content:
+                            try:
+                                json_content = content.split("```")[1].split("```")[0]
+                                content = json.loads(json_content.strip())
+                            except (IndexError, json.JSONDecodeError):
+                                pass
                     message_data.append(
                         {
                             "role": "system",
